@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -125,11 +125,8 @@ namespace gnote {
                            _("Plugins"));
 
       // TODO: Figure out a way to have these be placed in a specific order
-    std::list<PreferenceTabAddin *> tabAddins;
-    m_addin_manager.get_preference_tab_addins(tabAddins);
-    for(std::list<PreferenceTabAddin *>::const_iterator iter = tabAddins.begin();
-          iter != tabAddins.end(); ++iter) {
-      PreferenceTabAddin *tabAddin = *iter;
+    std::vector<PreferenceTabAddin*> tabAddins = m_addin_manager.get_preference_tab_addins();
+    for(auto tabAddin : tabAddins) {
       DBG_OUT("Adding preference tab addin: %s", 
               typeid(*tabAddin).name());
         try {
@@ -433,14 +430,13 @@ namespace gnote {
 
     // Populate the store with all the available SyncServiceAddins
     m_sync_addin_store = Gtk::ListStore::create(m_sync_addin_store_record);
-    std::list<sync::SyncServiceAddin*> addins;
-    m_addin_manager.get_sync_service_addins(addins);
-    addins.sort(CompareSyncAddinsByName());
-    for(std::list<sync::SyncServiceAddin*>::iterator addin = addins.begin(); addin != addins.end(); ++addin) {
-      if((*addin)->initialized()) {
+    std::vector<sync::SyncServiceAddin*> addins = m_addin_manager.get_sync_service_addins();
+    std::sort(addins.begin(), addins.end(), CompareSyncAddinsByName());
+    for(auto addin : addins) {
+      if(addin->initialized()) {
 	Gtk::TreeIter iter = m_sync_addin_store->append();
-	iter->set_value(0, (*addin));
-	m_sync_addin_iters[(*addin)->id()] = iter;
+	iter->set_value(0, addin);
+	m_sync_addin_iters[addin->id()] = iter;
       }
     }
 
@@ -971,7 +967,7 @@ namespace gnote {
     NoteBase::Ptr template_note = m_note_manager.get_or_create_template_note();
 
     // Open the template note
-    IGnote::obj().open_note(static_pointer_cast<Note>(template_note));
+    IGnote::obj().open_note(std::static_pointer_cast<Note>(template_note));
   }
 
 
@@ -1345,9 +1341,8 @@ namespace gnote {
 
   void PreferencesDialog::update_sync_services()
   {
-    std::list<sync::SyncServiceAddin*> new_addins;
-    m_addin_manager.get_sync_service_addins(new_addins);
-    std::list<sync::SyncServiceAddin*>::iterator remove_iter = new_addins.begin();
+    std::vector<sync::SyncServiceAddin*> new_addins = m_addin_manager.get_sync_service_addins();
+    auto remove_iter = new_addins.begin();
     while(remove_iter != new_addins.end()) {
       if(!(*remove_iter)->initialized()) {
         remove_iter = new_addins.erase(remove_iter);
@@ -1356,10 +1351,10 @@ namespace gnote {
         ++remove_iter;
       }
     }
-    new_addins.sort(CompareSyncAddinsByName());
+    std::sort(new_addins.begin(), new_addins.end(), CompareSyncAddinsByName());
 
     // Build easier-to-navigate list if addins currently in the combo
-    std::list<sync::SyncServiceAddin*> current_addins;
+    std::vector<sync::SyncServiceAddin*> current_addins;
     for(Gtk::TreeIter iter = m_sync_addin_store->children().begin();
         iter != m_sync_addin_store->children().end(); ++iter) {
       sync::SyncServiceAddin *current_addin = NULL;
@@ -1371,25 +1366,23 @@ namespace gnote {
 
     // Add new addins
     // TODO: Would be nice to insert these alphabetically instead
-    for(std::list<sync::SyncServiceAddin*>::iterator iter = new_addins.begin();
-        iter != new_addins.end(); ++iter) {
-      if(std::find(current_addins.begin(), current_addins.end(), *iter) == current_addins.end()) {
+    for(auto addin : new_addins) {
+      if(std::find(current_addins.begin(), current_addins.end(), addin) == current_addins.end()) {
 	Gtk::TreeIter iterator = m_sync_addin_store->append();
-	iterator->set_value(0, *iter);
-	m_sync_addin_iters[(*iter)->id()] = iterator;
+	iterator->set_value(0, addin);
+	m_sync_addin_iters[addin->id()] = iterator;
       }
     }
 
     // Remove deleted addins
-    for(std::list<sync::SyncServiceAddin*>::iterator current_addin = current_addins.begin();
-        current_addin != current_addins.end(); ++current_addin) {
-      if(std::find(new_addins.begin(), new_addins.end(), *current_addin) == new_addins.end()) {
-	Gtk::TreeIter iter = m_sync_addin_iters[(*current_addin)->id()];
+    for(auto current_addin : current_addins) {
+      if(std::find(new_addins.begin(), new_addins.end(), current_addin) == new_addins.end()) {
+	Gtk::TreeIter iter = m_sync_addin_iters[current_addin->id()];
 	m_sync_addin_store->erase(iter);
-	m_sync_addin_iters.erase((*current_addin)->id());
+	m_sync_addin_iters.erase(current_addin->id());
 
 	// FIXME: Lots of hacky stuff in here...rushing before freeze
-	if(*current_addin == m_selected_sync_addin) {
+	if(current_addin == m_selected_sync_addin) {
 	  if(m_sync_addin_prefs_widget != NULL && !m_sync_addin_prefs_widget->get_sensitive()) {
 	    on_reset_sync_addin_button(false);
           }
