@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013,2017 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ SyncServer::Ptr FuseSyncServiceAddin::create_sync_server()
   if(is_configured()) {
     if(!is_mounted() && !mount_fuse(true)) // mount_fuse may throw GnoteSyncException!
       throw std::runtime_error(("Could not mount " + m_mount_path).c_str());
-    server = FileSystemSyncServer::create(m_mount_path);
+    server = FileSystemSyncServer::create(Gio::File::create_for_path(m_mount_path));
   }
   else {
     throw new std::logic_error("create_sync_server called without being configured");
@@ -140,8 +140,7 @@ bool FuseSyncServiceAddin::save_configuration()
 
       // Test ability to read
       bool testFileFound = false;
-      std::list<Glib::ustring> files;
-      sharp::directory_get_files(m_mount_path, files);
+      std::vector<Glib::ustring> files = sharp::directory_get_files(m_mount_path);
       for(auto file : files) {
         if(file == testPath) {
           testFileFound = true;
@@ -326,7 +325,7 @@ bool FuseSyncServiceAddin::is_mounted()
   p.redirect_standard_output(true);
   p.file_name(m_mount_exe_path);
   p.start();
-  std::list<Glib::ustring> outputLines;
+  std::vector<Glib::ustring> outputLines;
   while(!p.standard_output_eof()) {
     Glib::ustring line = p.standard_output_read_line();
     outputLines.push_back(line);
