@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -307,12 +307,12 @@ namespace gnote {
     window->signal_backgrounded.connect(sigc::mem_fun(*this, &NoteSpellChecker::on_note_window_backgrounded));
   }
 
-  std::map<int, Gtk::Widget*> NoteSpellChecker::get_actions_popover_widgets() const
+  std::vector<gnote::PopoverWidget> NoteSpellChecker::get_actions_popover_widgets() const
   {
-    std::map<int, Gtk::Widget*> widgets = NoteAddin::get_actions_popover_widgets();
+    auto widgets = NoteAddin::get_actions_popover_widgets();
     if(m_enabled) {
-      utils::add_item_to_ordered_map(widgets, SPELL_CHECK_ORDER,
-        utils::create_popover_button("win.enable-spell-check", _("Check spelling")));
+      auto button = utils::create_popover_button("win.enable-spell-check", _("Check spelling"));
+      widgets.push_back(gnote::PopoverWidget(NOTE_SECTION_FLAGS, SPELL_CHECK_ORDER, button));
     }
     return widgets;
   }
@@ -447,9 +447,8 @@ namespace gnote {
   Tag::Ptr NoteSpellChecker::get_language_tag()
   {
     Tag::Ptr lang_tag;
-    std::list<Tag::Ptr> tags;
-    get_note()->get_tags(tags);
-    FOREACH(Tag::Ptr tag, tags) {
+    std::vector<Tag::Ptr> tags = get_note()->get_tags();
+    for(Tag::Ptr tag : tags) {
       if(tag->name().find(LANG_PREFIX) == 0) {
         lang_tag = tag;
         break;
@@ -862,7 +861,7 @@ namespace gnote {
 
     // Highlight previously unlinked text
     if (contains_text (renamed->get_title())) {
-      highlight_note_in_block(static_pointer_cast<Note>(renamed), get_buffer()->begin(), get_buffer()->end());
+      highlight_note_in_block(std::static_pointer_cast<Note>(renamed), get_buffer()->begin(), get_buffer()->end());
     }
   }
 
@@ -1048,7 +1047,7 @@ namespace gnote {
     // also works around the bug.
     if (link) {
       DBG_OUT ("Opening note '%s' on click...", link_name.c_str());
-      MainWindow::present_default(static_pointer_cast<Note>(link));
+      MainWindow::present_default(std::static_pointer_cast<Note>(link));
       return true;
     }
 
