@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -39,7 +39,6 @@ extern "C" {
 #include <gtkmm/textiter.h>
 #include <gtkmm/texttag.h>
 
-#include "base/macros.hpp"
 #include "noteaddin.hpp"
 #include "triehit.hpp"
 #include "utils.hpp"
@@ -94,7 +93,7 @@ namespace gnote {
     virtual void initialize() override;
     virtual void shutdown() override;
     virtual void on_note_opened() override;
-    virtual std::map<int, Gtk::Widget*> get_actions_popover_widgets() const override;
+    virtual std::vector<gnote::PopoverWidget> get_actions_popover_widgets() const override;
 
     static bool gtk_spell_available()
       { return true; }
